********************************************************
**** Example of using a Thermomiter Bar while       ****
**** indexing in Foxpro.                            ****
****                                                ****
**** NOTE:   The index will do strange things       ****
****         if it can't find function THRMIDX      ****
****         when using it outside of the PRG.      ****
****                                                ****
**** Written entirely by Charles G. Snyder          ****
**** (517) 339 9728                                 ****
**** Nov. 6 1992                                    ****
****                                                ****
**** Feel free to use this code however you wish    ****
********************************************************

SET TALK OFF
SET PROCEDURE TO INDX_TRM && ** So the CDX can find THRMIDX outside the PRG 
PUBLIC m_ymax,m_y,m_index && ** m_ymax  : Number of records in the database    
                             ** m_y     : Record counter 
USE NAMES.DBF             && ** any old database will work     
m_ymax=RECCOUNT()
m_y=0
@ 24,1 SAY "Indexing...           "
COPY STRU TO ERASE_ME      && IF THIS FILE EXISTS, DRAW THE THERMOMITER
INDEX ON LNAME+FNAME TAG NAME OF NAMES FOR THRMIDX()
ERASE ERASE_ME.DBF         && NOW THRMIDX WON'T CALL THERMOM
@ 24,1 CLEAR
BROW

********************* END OF MAIN ****************************************

FUNCTION THRMIDX
*** This function increments the record counter and calls your    ***
*** thermomiter function if ERASE_ME.DBF exists.                  ***
*** Returns TRUE to the INDEX statement                           *** 
IF FILE("ERASE_ME.DBF")      && 
   m_y=m_y+1
   DO THERMOM WITH m_y,m_ymax,18,5,20,75
ENDIF
RETURN .T.

**************************************************************************

PROCEDURE THERMOM
***************************************************
*** This is my simple Thermomiter procedure     ***
*** You can use any other thermomiter procedure,***
*** just change the DO line in THRMIDX.         ***
***************************************************
PARAMETER m_x,m_xmax,Y1,X1,Y2,X2    
       *  m_x    : location of counter
       *  m_xmax : maximum counter
       *  Y1,X1  : upper left of thermomiter
       *  Y2,X2  : lower right of thermomiter
*** If the first call, define the thermomiter window ***
IF m_x=1    
   PUBLIC m_last,m_normalc && ** m_last keeps track of the number of bars
   m_last=-1               && ** that will be needed to fill the thermomiter 
   m_normalc=SCHEME(1)     && ** so we can return color to normal later
   SET COLOR OF SCHEME 1 TO GR+/R,,GR+/R
   DEFINE WINDOW THERM FROM Y1,X1 TO Y2,X2 IN SCREEN SHADOW COLOR SCHEME 1
   ACTIVATE WINDOW THERM
ENDIF
*** PRINT THERMOMITER BAR ***
m_percent=m_x/m_xmax
m_bars=ROUND(m_percent*(X2-X1-2),0)  && ** total number of bars **
IF m_bars>m_last
   FOR x=m_last TO m_bars
      FOR y=0 TO (Y2-Y1-2)
         @ y,m_bars SAY ""
      NEXT y
   NEXT x
   m_last=m_bars
ENDIF
*** IF THERMOMITER IS FULL, CLEAN UP ***
IF m_x=m_xmax
   RELEASE WINDOW THERM
   SET COLOR OF SCHEME(1) To &m_normalc.    && ** Set color to normal  **
   RELEASE m_max, m_normalc
ENDIF
RETURN

********************************************
*********** END OF FILE ********************
********************************************
